<?php
// $Id: theme.inc,v 1.1.2.2 2010/05/20 01:37:29 quiptime Exp $

/**
 * @file
 * Theme functions for the Gallery Assist Comments module.
 */

/**
 * Display an title for the comments display.
 *
 * @param string $counter
 *   The themed counter.
 * @return string
 *   The themeable title of the comments.
 * @ingroup themeable
 */
function theme_gallery_assist_comments_comments_title($counter) {
  return '<h2 class="comments">'. t('Comments') .' '. $counter .'</h2>'."\n";
}

/**
 * Display the comments counter.
 *
 * @param int $counter
 * @return string
 *   The themeable counter.
 * @ingroup themeable
 */
function theme_gallery_assist_comments_comments_counter($counter) {
  return '<span class="ga-comment-counter">'. $counter .'</span>';
}

/**
 * Display the text for the "Display all comments" link.
 *
 * @see _gallery_assist_comments_area_links()
 *
 * @return string
 */
function theme_gallery_assist_comments_say_all() {
  return '<span class="ga-comment-say-all">'. t('All comments') .'</span>';
}

/**
 * Display the text for the "Display fewer comments" link.
 *
 * @see _gallery_assist_comments_area_links()
 *
 * @return string
 */
function theme_gallery_assist_comments_say_fewer() {
  return '<span class="ga-comment-say-fewer">'. t('Fewer comments') .'</span>';
}

/**
 * Display the comment form box.
 *
 * @param string $content
 *   The rendered form content.
 * @param string $position
 *   An position value. Allowed values:
 *   - above
 *   - below
 * @return string
 *   The themeable comment form.
 * @ingroup themeable
 */
function theme_gallery_assist_comments_form_box($content, $position) {
  $output = '';

  $output .= '<div id="ga-comment-area-form-'. $position .'">'."\n";
  $output .= $content;
  $output .= '</div>'."\n";

  return $output;
}

/**
 * Display an complete comment.
 *
 * @param object $comment
 *   A comment object.
 * @param string $classes
 *   The string contains CSS classes to apply to the comment container.
 * @return string
 *   A themeable comment.
 * @ingroup themeable
 *
 * Note:
 * The first opened div is closed in theme_gallery_assist_comments_container_links().
 */
function theme_gallery_assist_comments_container($comment, $classes) {
  $output = '';

  $output = '<div class="'. $classes .'">'."\n";
  $output .= '<div class="ga-comment-wrapper">'."\n";
  $output .= '<div class="clear-block">'."\n";
  $output .= '<div class="submitted-by">'. $comment->name .'</div>'."\n";
  $output .= '<div class="submitted-date">';
  $output .= $comment->created;
  $output .= '</div>'."\n";
  $output .= '</div>'."\n";
  $output .= '<div class="content">'."\n";
  $output .= $comment->comment;
  $output .= '</div>'."\n";
  $output .= '</div>'."\n";

  return $output;
}

/**
 * Display the comment links container.
 *
 * @param object $comment
 *   A comment object.
 * @param string $links
 *   Contain the comment links unpublish/publish, delete.
 * @param array $classes
 *   The string contains CSS classes to apply to the links container.
 * @return string
 *   The themeable comment links container.
 * @ingroup themeable
 *
 * Note:
 * The last closed div tag is opened in theme_gallery_assist_comments_container().
 */
function theme_gallery_assist_comments_container_links($comment, $links, $classes) {
  $output = '';

  $output = '<div class="'. $classes .'">'."\n";
  $output .= $links;
  $output .= '</div>'."\n";
  $output .= '</div>'."\n";

  return $output;
}

/**
 * Display the comment submitted information.
 *
 * @see gallery_assist_comments_submitted()
 * @see gallery_assist_comments_load_content()
 *
 * @param object $comment
 *   A comment object.
 * @param string $submitted
 *   The HTML formatted submitted line.
 * @return string
 *   The themeable submitted date.
 * @ingroup themeable
 */
function theme_gallery_assist_comments_submitted($submitted) {
  return '<span class="ga-comment-submitted">'. $submitted .'</span>';
}

/**
 *  Display comments content.
 *
 * @see gallery_assist_comments_submitted()
 * @see gallery_assist_comments_load_content()
 *
 * @param string $content
 *   The HTML formatted comments content.
 * @return string
 *   The themeable comments content.
 * @ingroup themeable
 */
function theme_gallery_assist_comments_content($content) {
  return '<div id="ga-comment-content" class="content">'. $content .'</div>';
}
